@@ -11,7 +11,7 @@
 # URL        : https://github.com/john-james-ai/studioai                                           #
 # ------------------------------------------------------------------------------------------------ #
 # Created    : Thursday August 10th 2023 08:29:08 pm                                               #
-# Modified   : Friday September 29th 2023 09:01:19 pm                                              #
+# Modified   : Wednesday June 26th 2024 07:13:44 pm                                                #
 # ------------------------------------------------------------------------------------------------ #
 # License    : MIT License                                                                         #
 # Copyright  : (c) 2023 John James                                                                 #
@@ -23,9 +23,8 @@ from typing import Callable, Union, List
 
 import pandas as pd
 
-from studioai.stats.descriptive.summary import SummaryStats
-from studioai.visual.visualizer import Visualizer, SeabornCanvas
-from studioai.stats.inferential.test import Inference
+from studioai.analysis.stats.descriptive.summary import SummaryStats
+from studioai.analysis.visualize.visualizer import Visualizer, SeabornCanvas
 
 # ------------------------------------------------------------------------------------------------ #
 logger = logging.getLogger(__name__)
@@ -44,8 +43,6 @@ class Dataset(ABC):
     def __init__(self, df: pd.DataFrame) -> None:
         self._df = df
         self._visualizer = Visualizer(canvas=SeabornCanvas())
-        self._inference = Inference()
-        self._tests = {}
 
     def __len__(self):
         """Returns the length of the dataset."""
@@ -55,16 +52,6 @@ class Dataset(ABC):
     def summary(self) -> pd.DataFrame:
         """Returns a summary of the dataset contents in DataFrame format"""
 
-    @property
-    def plot(self) -> Visualizer:  # pragma: no cover
-        self._visualizer.data = self._df
-        return self._visualizer
-
-    @property
-    def stats(self) -> Visualizer:  # pragma: no cover
-        self._inference.data = self._df
-        return self._inference
-
     @property
     def columns(self) -> list:
         """Returns a list containing the names of the columns in the dataset."""
@@ -115,13 +102,14 @@ class Dataset(ABC):
 
         info = self._df.dtypes.to_frame().reset_index()
         info.columns = ["Column", "DataType"]
-        info["Complete"] = self._df.count().values
+        info["Valid"] = self._df.count().values
         info["Null"] = self._df.isna().sum().values
-        info["Completeness"] = info["Complete"] / self._df.shape[0]
-        info["Unique"] = self._df.nunique().values
-        info["Duplicate"] = self._df.shape[0] - self._df.nunique().values
-        info["Uniqueness"] = self._df.nunique().values / self._df.shape[0]
-        info["Size"] = self._df.memory_usage(deep=True, index=False).to_frame().reset_index()[0]
+        info["Validity"] = info["Valid"] / self._df.shape[0]
+        info["Cardinality"] = self._df.nunique().values
+        info["Percent Unique"] = self._df.nunique().values / self._df.shape[0]
+        info["Size"] = (
+            self._df.memory_usage(deep=True, index=False).to_frame().reset_index()[0]
+        )
         info = round(info, 2)
         return self._format(df=info)
 
@@ -132,7 +120,11 @@ class Dataset(ABC):
 
     # ------------------------------------------------------------------------------------------- #
     def sample(
-        self, n: int = 5, frac: float = None, replace: bool = False, random_state: int = None
+        self,
+        n: int = 5,
+        frac: float = None,
+        replace: bool = False,
+        random_state: int = None,
     ) -> pd.DataFrame:
         """Returns a sample from the FOG Dataset
 
@@ -263,7 +255,9 @@ class Dataset(ABC):
         if isinstance(self._df[x], pd.Series):
             abs = (
                 self._df[x]
-                .value_counts(normalize=False, sort=sort, bins=bins, ascending=ascending)
+                .value_counts(
+                    normalize=False, sort=sort, bins=bins, ascending=ascending
+                )
                 .to_frame()
             )
             rel = (
@@ -273,10 +267,14 @@ class Dataset(ABC):
             )
         else:
             abs = (
-                self._df[x].value_counts(normalize=False, sort=sort, ascending=ascending).to_frame()
+                self._df[x]
+                .value_counts(normalize=False, sort=sort, ascending=ascending)
+                .to_frame()
             )
             rel = (
-                self._df[x].value_counts(normalize=True, sort=sort, ascending=ascending).to_frame()
+                self._df[x]
+                .value_counts(normalize=True, sort=sort, ascending=ascending)
+                .to_frame()
             )
         freq = abs.join(rel, on=x)
         freq.loc["Total"] = freq.sum()
@@ -287,24 +285,10 @@ class Dataset(ABC):
         return freq
 
     # ------------------------------------------------------------------------------------------- #
-    def countstats(self, x: str) -> pd.DataFrame:
-        """Computes descriptive statistics of counts for a variable.
-
-        The value counts of the x variable are obtained and descriptive statistics are
-        computed showing min, max, average, std, and quantiles of counts.
-
-        Args:
-            x (str): Name of a variable in the dataset
-
-        Returns:
-            Value Counts: pd.DataFrame
-            Count Statistics: pd.DataFrame
-
-        """
-        counts = self._df[x].value_counts().to_frame().reset_index()
-        cs = counts["count"].describe().to_frame()
-        cs.columns = [x]
-        return counts, cs.T
+    @property
+    def plot(self) -> Visualizer:  # pragma: no cover
+        self._visualizer.data = self._df
+        return self._visualizer
 
     # ------------------------------------------------------------------------------------------- #
     #                                PRIVATE METHODS                                              #
